struct McpRequestCancellationBridge {
stop: Arc<AtomicBool>,
monitor: Option<JoinHandle<()>>,
context: Option<RequestContext<RoleServer>>,
}Expand description
Bridge one RMCP request cancellation token into synchronous index work.
Fields
stop: Arc<AtomicBool>Signal used to stop the request-local cancellation monitor.
monitor: Option<JoinHandle<()>>Join handle for the bounded request-local monitor thread.
context: Option<RequestContext<RoleServer>>Owned RMCP request context retained for the final cancellation check.
Implementations
Sourceimpl McpRequestCancellationBridge
impl McpRequestCancellationBridge
Sourcefn start(
context: RequestContext<RoleServer>,
control: &IndexWorkControl,
) -> Result<Self, CliError>
fn start( context: RequestContext<RoleServer>, control: &IndexWorkControl, ) -> Result<Self, CliError>
Start a request-local monitor from one owned RMCP context.
Sourcefn start_with_probe_and_context<P>(
probe: P,
control: &IndexWorkControl,
context: Option<RequestContext<RoleServer>>,
) -> Result<Self, CliError>
fn start_with_probe_and_context<P>( probe: P, control: &IndexWorkControl, context: Option<RequestContext<RoleServer>>, ) -> Result<Self, CliError>
Start a cancellation monitor and retain its owning request context.
Sourcefn is_cancelled(&self) -> bool
fn is_cancelled(&self) -> bool
Return whether RMCP canceled the owning request.