struct McpSelectedRoot(PathBuf);Expand description
Role-typed selected root for MCP path routing.
Tuple Fields
0: PathBufImplementations
Sourceimpl McpSelectedRoot
impl McpSelectedRoot
Sourcefn from_state(state: &McpProjectState) -> Self
fn from_state(state: &McpProjectState) -> Self
Build the selected root wrapper from active project state.
Sourcefn repo_key_for(
&self,
path: &McpAbsolutePath,
) -> Result<Option<McpRepoKey>, CliError>
fn repo_key_for( &self, path: &McpAbsolutePath, ) -> Result<Option<McpRepoKey>, CliError>
Convert an absolute path inside this root into a repository key.